Changelog
=========

0.1.3 (2017-01-04)
------------------

Fix
~~~

- Fixing testing for python 3.2 and 2.6. [Luis Alejandro Martínez
  Faneyth]

0.1.2 (2017-01-04)
------------------

New
~~~

- Adding gitchangelog configuration file. [Luis Alejandro Martínez
  Faneyth]

- Adding support to python 2.6 (closes #10). [Luis Alejandro Martínez
  Faneyth]

0.1.1 (2016-11-24)
------------------

New
~~~

- Adding Contributor License Agreement. [Luis Alejandro Martínez
  Faneyth]

Changes
~~~~~~~

- Adding new changelog entries. [Luis Alejandro Martínez Faneyth]

Fix
~~~

- Fixing bumpversion config. [Luis Alejandro Martínez Faneyth]

- Fixing typo. [Luis Alejandro Martínez Faneyth]

- Catching exceptions on package discovery as described in #3. [REF]
  Using find_packages from setuptools to discover packages. [Luis
  Alejandro Martínez Faneyth]

Other
~~~~~

- Bump version: 0.1.0 → 0.1.1. [Luis Alejandro Martínez Faneyth]

0.1.0 (2016-11-23)
------------------

Changes
~~~~~~~

- Improving README. [Luis Alejandro Martínez Faneyth]

- Improving RST markup. [Luis Alejandro Martínez Faneyth]

- Improving documentation. [REF] Configuring codeclimate. [Luis
  Alejandro Martínez Faneyth]

- Completing API documentation. [REF] Finishing commandline programming.
  [Luis Alejandro Martínez Faneyth]

- Temporarily increasing McCabe index to 20 to pass tests. [REF]
  Updating requirements versions. [REF] Improving documentation. [Luis
  Alejandro Martínez Faneyth]

- Improving documentation. [Luis Alejandro Martínez Faneyth]

- Correcting code style. [Luis Alejandro Martínez Faneyth]

- Improving documentation of functions. [REF] Porting snakefood's code
  to python 3.x. [REF] Various coe style corrections. [Luis Alejandro
  Martínez Faneyth]

- Adding code from snakefood because it doesn't support py3k. [REF]
  Fixing PEP8 errors. [Luis Alejandro Martínez Faneyth]

- Improving documentation. [REF] Adding download progress to "update"
  command. [Luis Alejandro Martínez Faneyth]

- Improving documentation. [REF] Updating visual style. [REF]
  Reorganizing code. [Luis Alejandro Martínez Faneyth]

- Updating visual style. [Luis Alejandro Martínez Faneyth]

- General refactoring of structure and code. [ADD] Adding projecto
  boilerplate. [ADD] Programming of "guess" command. [ADD] Adding visual
  style. [Luis Alejandro Martínez Faneyth]

Fix
~~~

- Correcting minor issues. [Luis Alejandro Martínez Faneyth]

- Fixing typo. [Luis Alejandro Martínez Faneyth]

Other
~~~~~

- 0.1.0 release. [Luis Alejandro Martínez Faneyth]

- Add Gitter badge. [The Gitter Badger]

- [DEL] Removing unnecessary tests. [REF] Reorganizing code. [REF]
  Documenting functions. [REF] Starting some unit tests. [Luis Alejandro
  Martínez Faneyth]

- Initial commit. [Luis Alejandro Martínez Faneyth]


